      program CallLINGO
!
! Sample FORTRAN program that calls the LINGO DLL to solve:
!
!    MAX=20*X+30*Y;
!    X<30;
!    Y<50;
!    X+2*Y<120;
!
      implicit none

      interface

         integer function LScloseLogFileLng( pLINGO)
            !ms$attributes stdcall, alias:'_LScloseLogFileLng@4' ::
     +       LScloseLogFileLng
            integer pLINGO                     [VALUE]
         end function LScloseLogFileLng

         integer function LScreateEnvLng
            !ms$attributes stdcall, alias:'_LScreateEnvLng@0' ::
     +       LScreateEnvLng
         end function LScreateEnvLng

         integer function LSdeleteEnvLng( pLINGO)
            !ms$attributes stdcall, alias:'_LSdeleteEnvLng@4' ::
     +       LSdeleteEnvLng
            integer pLINGO                     [VALUE]
         end function LSdeleteEnvLng

         integer function LSexecuteScriptLng( pLINGO, pcScript);
            !ms$attributes stdcall, alias:'_LSexecuteScriptLng@8' ::
     +       LSexecuteScriptLng
            integer pLINGO                     [VALUE]
            character pcScript                 [REFERENCE]
         end function LSexecuteScriptLng

         integer function LSopenLogFileLng( pLINGO, pcLogFile)
            !ms$attributes stdcall, alias:'_LSopenLogFileLng@8' ::
     +       LSopenLogFileLng
            integer pLINGO                     [VALUE]
            character pcLogFile                [REFERENCE]
         end function LSopenLogFileLng

         integer function LSsetPointerLng( pLINGO, pdPointer, 
     +    nPointersNow);
            !ms$attributes stdcall, alias:'_LSsetPointerLng@12' ::
     +       LSsetPointerLng
            integer pLINGO                     [VALUE]
            real*8 pdPointer                   [REFERENCE]
            integer nPointersNow               [REFERENCE]
         end function LSsetPointerLng

      end interface

      integer pLINGO, nError, nPointers
      real*8 dObj, dX, dY
      character*256 cScript
      
	nError = -1

! Create a LINGO environment object
      pLINGO = LScreateEnvLng()
      if ( pLINGO .eq. 0) go to 9001

! Open up LINGO's log file
      nError = LSopenLogFileLng( pLINGO, "lingo.log");
      if ( nError .ne. 0) go to 9001

! Establish pointers for transferring data to/from LINGO
      nError = LSsetPointerLng( pLINGO, dObj, nPointers)
      if ( nError .ne. 0) go to 9001

      nError = LSsetPointerLng( pLINGO, dX, nPointers)
      if ( nError .ne. 0) go to 9001

      nError = LSsetPointerLng( pLINGO, dY, nPointers)
      if ( nError .ne. 0) go to 9001

! Build the command script
      cScript = 'SET ECHOIN 1' // char(10) //
     + 'MODEL:' // char(10) //
     + '[OBJECTIVE] MAX=20*X+30*Y;' // char(10) //
     + 'X<30;' // char(10) //
     + 'Y<50;' // char(10) //
     + 'X+2*Y<120;' // char(10) //
     + 'DATA:' // char(10) //
     + '@POINTER( 1) = OBJECTIVE;' // char(10) //
     + '@POINTER( 2) = X;' // char(10) //
     + '@POINTER( 3) = Y;' // char(10) //
     + 'ENDDATA' // char(10) //
     + 'END' // char(10) //
     + 'GO' // char(10) //
     + 'QUIT' // char(10)

! Pass the command script to LINGO for execution
      nError = LSexecuteScriptLng( pLINGO, cScript)
      if ( nError .ne. 0) go to 9001

! Close the log file
      nError = LScloseLogFileLng( pLINGO);
      if ( nError .ne. 0) go to 9001

! Display the solution
      write(6,*) 'Objective =', dObj
      write(6,*) 'X =', dX
      write(6,*) 'Y =', dY

      go to 9100

 9001 continue
      write( 6, *) 'LINGO Error Code: ', nError
      go to 9999

 9100 continue

! Delete the LINGO environment
      call LSdeleteEnvLng( pLINGO);

      pause 'Press Enter ...'

 9999 continue
      end
